==> openshift-model-hive-6.7.2-sources.jar: io/fabric8/openshift/api/model/hive/v1/HiveConfigSpecBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class HiveConfigSpecBuilder extends HiveConfigSpecFluentImpl<HiveConfigSpecBuilder> implements VisitableBuilder<HiveConfigSpec,HiveConfigSpecBuilder>{
  public HiveConfigSpecBuilder() {
    this(false);
  }
  public HiveConfigSpecBuilder(Boolean validationEnabled) {
    this(new HiveConfigSpec(), validationEnabled);
  }
  public HiveConfigSpecBuilder(HiveConfigSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public HiveConfigSpecBuilder(HiveConfigSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new HiveConfigSpec(), validationEnabled);
  }
  public HiveConfigSpecBuilder(HiveConfigSpecFluent<?> fluent,HiveConfigSpec instance) {
    this(fluent, instance, false);
  }
  public HiveConfigSpecBuilder(HiveConfigSpecFluent<?> fluent,HiveConfigSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withAdditionalCertificateAuthoritiesSecretRef(instance.getAdditionalCertificateAuthoritiesSecretRef());
      fluent.withArgoCDConfig(instance.getArgoCDConfig());
      fluent.withAwsPrivateLink(instance.getAwsPrivateLink());
      fluent.withBackup(instance.getBackup());
      fluent.withControllersConfig(instance.getControllersConfig());
      fluent.withDeleteProtection(instance.getDeleteProtection());
      fluent.withDeprovisionsDisabled(instance.getDeprovisionsDisabled());
      fluent.withDisabledControllers(instance.getDisabledControllers());
      fluent.withExportMetrics(instance.getExportMetrics());
      fluent.withFailedProvisionConfig(instance.getFailedProvisionConfig());
      fluent.withFeatureGates(instance.getFeatureGates());
      fluent.withGlobalPullSecretRef(instance.getGlobalPullSecretRef());
      fluent.withLogLevel(instance.getLogLevel());
      fluent.withMaintenanceMode(instance.getMaintenanceMode());
      fluent.withManagedDomains(instance.getManagedDomains());
      fluent.withReleaseImageVerificationConfigMapRef(instance.getReleaseImageVerificationConfigMapRef());
      fluent.withServiceProviderCredentialsConfig(instance.getServiceProviderCredentialsConfig());
      fluent.withSyncSetReapplyInterval(instance.getSyncSetReapplyInterval());
      fluent.withTargetNamespace(instance.getTargetNamespace());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public HiveConfigSpecBuilder(HiveConfigSpec instance) {
    this(instance,false);
  }
  public HiveConfigSpecBuilder(HiveConfigSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withAdditionalCertificateAuthoritiesSecretRef(instance.getAdditionalCertificateAuthoritiesSecretRef());
      this.withArgoCDConfig(instance.getArgoCDConfig());
      this.withAwsPrivateLink(instance.getAwsPrivateLink());
      this.withBackup(instance.getBackup());
      this.withControllersConfig(instance.getControllersConfig());
      this.withDeleteProtection(instance.getDeleteProtection());
      this.withDeprovisionsDisabled(instance.getDeprovisionsDisabled());
      this.withDisabledControllers(instance.getDisabledControllers());
      this.withExportMetrics(instance.getExportMetrics());
      this.withFailedProvisionConfig(instance.getFailedProvisionConfig());
      this.withFeatureGates(instance.getFeatureGates());
      this.withGlobalPullSecretRef(instance.getGlobalPullSecretRef());
      this.withLogLevel(instance.getLogLevel());
      this.withMaintenanceMode(instance.getMaintenanceMode());
      this.withManagedDomains(instance.getManagedDomains());
      this.withReleaseImageVerificationConfigMapRef(instance.getReleaseImageVerificationConfigMapRef());
      this.withServiceProviderCredentialsConfig(instance.getServiceProviderCredentialsConfig());
      this.withSyncSetReapplyInterval(instance.getSyncSetReapplyInterval());
      this.withTargetNamespace(instance.getTargetNamespace());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  HiveConfigSpecFluent<?> fluent;
  Boolean validationEnabled;
  public HiveConfigSpec build() {
    HiveConfigSpec buildable = new HiveConfigSpec(fluent.getAdditionalCertificateAuthoritiesSecretRef(),fluent.getArgoCDConfig(),fluent.getAwsPrivateLink(),fluent.getBackup(),fluent.getControllersConfig(),fluent.getDeleteProtection(),fluent.getDeprovisionsDisabled(),fluent.getDisabledControllers(),fluent.getExportMetrics(),fluent.getFailedProvisionConfig(),fluent.getFeatureGates(),fluent.getGlobalPullSecretRef(),fluent.getLogLevel(),fluent.getMaintenanceMode(),fluent.getManagedDomains(),fluent.getReleaseImageVerificationConfigMapRef(),fluent.getServiceProviderCredentialsConfig(),fluent.getSyncSetReapplyInterval(),fluent.getTargetNamespace());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-hive-6.8.0-sources.jar: io/fabric8/openshift/api/model/hive/v1/HiveConfigSpecBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class HiveConfigSpecBuilder extends HiveConfigSpecFluent<HiveConfigSpecBuilder> implements VisitableBuilder<HiveConfigSpec,HiveConfigSpecBuilder>{
  public HiveConfigSpecBuilder() {
    this(false);
  }
  public HiveConfigSpecBuilder(Boolean validationEnabled) {
    this(new HiveConfigSpec(), validationEnabled);
  }
  public HiveConfigSpecBuilder(HiveConfigSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public HiveConfigSpecBuilder(HiveConfigSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new HiveConfigSpec(), validationEnabled);
  }
  public HiveConfigSpecBuilder(HiveConfigSpecFluent<?> fluent,HiveConfigSpec instance) {
    this(fluent, instance, false);
  }
  public HiveConfigSpecBuilder(HiveConfigSpecFluent<?> fluent,HiveConfigSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new HiveConfigSpec());

    if (instance != null) {
      fluent.withAdditionalCertificateAuthoritiesSecretRef(instance.getAdditionalCertificateAuthoritiesSecretRef());
      fluent.withArgoCDConfig(instance.getArgoCDConfig());
      fluent.withAwsPrivateLink(instance.getAwsPrivateLink());
      fluent.withBackup(instance.getBackup());
      fluent.withControllersConfig(instance.getControllersConfig());
      fluent.withDeleteProtection(instance.getDeleteProtection());
      fluent.withDeprovisionsDisabled(instance.getDeprovisionsDisabled());
      fluent.withDisabledControllers(instance.getDisabledControllers());
      fluent.withExportMetrics(instance.getExportMetrics());
      fluent.withFailedProvisionConfig(instance.getFailedProvisionConfig());
      fluent.withFeatureGates(instance.getFeatureGates());
      fluent.withGlobalPullSecretRef(instance.getGlobalPullSecretRef());
      fluent.withLogLevel(instance.getLogLevel());
      fluent.withMaintenanceMode(instance.getMaintenanceMode());
      fluent.withManagedDomains(instance.getManagedDomains());
      fluent.withReleaseImageVerificationConfigMapRef(instance.getReleaseImageVerificationConfigMapRef());
      fluent.withServiceProviderCredentialsConfig(instance.getServiceProviderCredentialsConfig());
      fluent.withSyncSetReapplyInterval(instance.getSyncSetReapplyInterval());
      fluent.withTargetNamespace(instance.getTargetNamespace());
      fluent.withAdditionalCertificateAuthoritiesSecretRef(instance.getAdditionalCertificateAuthoritiesSecretRef());
      fluent.withArgoCDConfig(instance.getArgoCDConfig());
      fluent.withAwsPrivateLink(instance.getAwsPrivateLink());
      fluent.withBackup(instance.getBackup());
      fluent.withControllersConfig(instance.getControllersConfig());
      fluent.withDeleteProtection(instance.getDeleteProtection());
      fluent.withDeprovisionsDisabled(instance.getDeprovisionsDisabled());
      fluent.withDisabledControllers(instance.getDisabledControllers());
      fluent.withExportMetrics(instance.getExportMetrics());
      fluent.withFailedProvisionConfig(instance.getFailedProvisionConfig());
      fluent.withFeatureGates(instance.getFeatureGates());
      fluent.withGlobalPullSecretRef(instance.getGlobalPullSecretRef());
      fluent.withLogLevel(instance.getLogLevel());
      fluent.withMaintenanceMode(instance.getMaintenanceMode());
      fluent.withManagedDomains(instance.getManagedDomains());
      fluent.withReleaseImageVerificationConfigMapRef(instance.getReleaseImageVerificationConfigMapRef());
      fluent.withServiceProviderCredentialsConfig(instance.getServiceProviderCredentialsConfig());
      fluent.withSyncSetReapplyInterval(instance.getSyncSetReapplyInterval());
      fluent.withTargetNamespace(instance.getTargetNamespace());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public HiveConfigSpecBuilder(HiveConfigSpec instance) {
    this(instance,false);
  }
  public HiveConfigSpecBuilder(HiveConfigSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new HiveConfigSpec());

    if (instance != null) {
      this.withAdditionalCertificateAuthoritiesSecretRef(instance.getAdditionalCertificateAuthoritiesSecretRef());
      this.withArgoCDConfig(instance.getArgoCDConfig());
      this.withAwsPrivateLink(instance.getAwsPrivateLink());
      this.withBackup(instance.getBackup());
      this.withControllersConfig(instance.getControllersConfig());
      this.withDeleteProtection(instance.getDeleteProtection());
      this.withDeprovisionsDisabled(instance.getDeprovisionsDisabled());
      this.withDisabledControllers(instance.getDisabledControllers());
      this.withExportMetrics(instance.getExportMetrics());
      this.withFailedProvisionConfig(instance.getFailedProvisionConfig());
      this.withFeatureGates(instance.getFeatureGates());
      this.withGlobalPullSecretRef(instance.getGlobalPullSecretRef());
      this.withLogLevel(instance.getLogLevel());
      this.withMaintenanceMode(instance.getMaintenanceMode());
      this.withManagedDomains(instance.getManagedDomains());
      this.withReleaseImageVerificationConfigMapRef(instance.getReleaseImageVerificationConfigMapRef());
      this.withServiceProviderCredentialsConfig(instance.getServiceProviderCredentialsConfig());
      this.withSyncSetReapplyInterval(instance.getSyncSetReapplyInterval());
      this.withTargetNamespace(instance.getTargetNamespace());
      this.withAdditionalCertificateAuthoritiesSecretRef(instance.getAdditionalCertificateAuthoritiesSecretRef());
      this.withArgoCDConfig(instance.getArgoCDConfig());
      this.withAwsPrivateLink(instance.getAwsPrivateLink());
      this.withBackup(instance.getBackup());
      this.withControllersConfig(instance.getControllersConfig());
      this.withDeleteProtection(instance.getDeleteProtection());
      this.withDeprovisionsDisabled(instance.getDeprovisionsDisabled());
      this.withDisabledControllers(instance.getDisabledControllers());
      this.withExportMetrics(instance.getExportMetrics());
      this.withFailedProvisionConfig(instance.getFailedProvisionConfig());
      this.withFeatureGates(instance.getFeatureGates());
      this.withGlobalPullSecretRef(instance.getGlobalPullSecretRef());
      this.withLogLevel(instance.getLogLevel());
      this.withMaintenanceMode(instance.getMaintenanceMode());
      this.withManagedDomains(instance.getManagedDomains());
      this.withReleaseImageVerificationConfigMapRef(instance.getReleaseImageVerificationConfigMapRef());
      this.withServiceProviderCredentialsConfig(instance.getServiceProviderCredentialsConfig());
      this.withSyncSetReapplyInterval(instance.getSyncSetReapplyInterval());
      this.withTargetNamespace(instance.getTargetNamespace());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  HiveConfigSpecFluent<?> fluent;
  Boolean validationEnabled;
  public HiveConfigSpec build() {
    HiveConfigSpec buildable = new HiveConfigSpec(fluent.buildAdditionalCertificateAuthoritiesSecretRef(),fluent.buildArgoCDConfig(),fluent.buildAwsPrivateLink(),fluent.buildBackup(),fluent.buildControllersConfig(),fluent.getDeleteProtection(),fluent.getDeprovisionsDisabled(),fluent.getDisabledControllers(),fluent.getExportMetrics(),fluent.buildFailedProvisionConfig(),fluent.buildFeatureGates(),fluent.buildGlobalPullSecretRef(),fluent.getLogLevel(),fluent.getMaintenanceMode(),fluent.buildManagedDomains(),fluent.buildReleaseImageVerificationConfigMapRef(),fluent.buildServiceProviderCredentialsConfig(),fluent.getSyncSetReapplyInterval(),fluent.getTargetNamespace());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
